@@ -22,16 +22,19 @@
 
 package com.adobe.epubcheck.util;
 
-public enum EPUBVersion {
-	VERSION_2(2f), VERSION_3(3f);
+public enum EPUBVersion
+{
+  Unknown("unknown"), VERSION_2("2.0.1"), VERSION_3("3.0.1");
 
-	private Float version;
+  private final String version;
 
-	EPUBVersion(float version) {
-		this.version = new Float(version);
-	}
+  EPUBVersion(String version)
+  {
+    this.version = version;
+  }
 
-	public String toString() {
-		return version.toString();
-	}
-};
+  public String toString()
+  {
+    return version;
+  }
+}
