@@ -22,15 +22,17 @@
 
 package com.adobe.epubcheck.xml;
 
-public interface XMLHandler {
+public interface XMLHandler
+{
 
-	public void characters(char[] chars, int arg1, int arg2);
+  public void characters(char[] chars, int arg1, int arg2);
 
-	public void ignorableWhitespace(char[] chars, int arg1, int arg2);
+  public void ignorableWhitespace(char[] chars, int arg1, int arg2);
 
-	public void startElement();
+  public void startElement();
 
-	public void endElement();
+  public void endElement();
 
-	public void processingInstruction(String arg0, String arg1);
+  public void processingInstruction(String arg0, String arg1);
+  
 }
