@@ -2,25 +2,14 @@ package org.idpf.epubcheck.util.css;
 
 import static org.idpf.epubcheck.util.css.CssTokenList.Filters.FILTER_NONE;
 import static org.idpf.epubcheck.util.css.CssTokenList.Filters.FILTER_S_CMNT;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 
-import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.PrintStream;
 import java.io.StringReader;
+import java.net.URL;
 import java.util.List;
 
-import org.idpf.epubcheck.util.css.CssContentHandler;
-import org.idpf.epubcheck.util.css.CssErrorHandler;
-import org.idpf.epubcheck.util.css.CssExceptions;
-import org.idpf.epubcheck.util.css.CssLocation;
-import org.idpf.epubcheck.util.css.CssParser;
-import org.idpf.epubcheck.util.css.CssSource;
-import org.idpf.epubcheck.util.css.CssToken;
-import org.idpf.epubcheck.util.css.CssTokenList;
 import org.idpf.epubcheck.util.css.CssExceptions.CssException;
 import org.idpf.epubcheck.util.css.CssExceptions.CssScannerException;
 import org.idpf.epubcheck.util.css.CssGrammar.CssAtRule;
@@ -861,27 +850,23 @@ public class CssParserTest {
 	
 	@Test
 	public void testParserFile001() throws Exception {		
-		File f = new File(CssInputStreamTest.PATH_TEST_BASE, "counter-styles.css");
-		HandlerImpl handler = checkBasics(execFile(f, false));						
+		HandlerImpl handler = checkBasics(execFile("counter-styles.css", false));						
 		assertEquals(31, handler.atRules.size());
 	}
 	
 	@Test
 	public void testParserFile002() throws Exception {		
-		File f = new File(CssInputStreamTest.PATH_TEST_BASE, "samples.css");
-		checkBasics(execFile(f, false));								
+		checkBasics(execFile("counter-styles.css", false));								
 	}
 	
 	@Test
 	public void testParserFile003() throws Exception {		
-		File f = new File(CssInputStreamTest.PATH_TEST_BASE, "caja.css");
-		checkBasics(execFile(f, false));								
+		checkBasics(execFile("counter-styles.css", false));								
 	}
 	
 	@Test
 	public void testParserFile004() throws Exception {		
-		File f = new File(CssInputStreamTest.PATH_TEST_BASE, "flexbox.css");
-		checkBasics(execFile(f, false));								
+		checkBasics(execFile("counter-styles.css", false));								
 	}
 	
 	@Test
@@ -1169,13 +1154,13 @@ public class CssParserTest {
 	@Test
 	public void testIssue231() throws Exception {
 		//line numbers, CR+LF lf=\n, cr=\r
-		HandlerImpl handler = execFile(new File(CssInputStreamTest.PATH_TEST_BASE, "issue231-crlf.css"), false);
+		HandlerImpl handler = execFile("issue231-crlf.css", false);
 		int line = handler.errors.get(0).location.line;
 		int col = handler.errors.get(0).location.col;
 		assertEquals(102, line);		
 		assertEquals(1, col);
 		
-		handler = execFile(new File(CssInputStreamTest.PATH_TEST_BASE, "issue231-lf.css"), false);
+		handler = execFile("issue231-lf.css", false);
 		line = handler.errors.get(0).location.line;
 		col = handler.errors.get(0).location.col;
 		assertEquals(102, line);		
@@ -1184,28 +1169,37 @@ public class CssParserTest {
 	
 	@Test
 	public void testIssue240_1() throws Exception {
-		HandlerImpl handler = execFile(new File(CssInputStreamTest.PATH_TEST_BASE, "issue240-1.css"), false);
+		HandlerImpl handler = execFile("issue240-1.css", false);
 		assertEquals(0, handler.errors.size());		
 	}
 	
 	@Test
 	public void testIssue240_2() throws Exception {
-		HandlerImpl handler = execFile(new File(CssInputStreamTest.PATH_TEST_BASE, "issue240-2.css"), false);
+		HandlerImpl handler = execFile("issue240-2.css", false);
 		assertEquals(0, handler.errors.size());		
 	}
 		
 	@Test
 	public void testIssue241() throws Exception {
-		HandlerImpl handler = execFile(new File(CssInputStreamTest.PATH_TEST_BASE, "issue241.css"), false);
+		HandlerImpl handler = execFile("issue241.css", false);
 		assertEquals(0, handler.errors.size());			
 	}
 	
 	@Test
 	public void testIssue262() throws Exception {
-		HandlerImpl handler = execFile(new File(CssInputStreamTest.PATH_TEST_BASE, "issue262.css"), false);
+		HandlerImpl handler = execFile("issue262.css", false);
 		assertEquals(0, handler.errors.size());		
 	}
 	
+	@Test
+	public void testIssue333() throws Exception {
+//	  String s = "color: rgba(198,215,225,0);";
+	  String s = "background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, rgba(198,215,225,0)), color-stop(100%, rgba(198,215,225,1)));";
+    HandlerImpl handler = execStyleAttr(s, false);                        
+    assertEquals(1, handler.declarations.size());
+    assertEquals(0, handler.errors.size());   
+	}
+	
 	HandlerImpl exec(String css, boolean debug) throws IOException, CssException {		
 		HandlerImpl handler = new HandlerImpl(debug);
 		new CssParser().parse(new StringReader(css), CssLocation.NO_SID, handler, handler);
@@ -1218,9 +1212,10 @@ public class CssParserTest {
 		return handler;
 	}
 	
-	HandlerImpl execFile(File f, boolean debug) throws IOException, CssException {		
+	HandlerImpl execFile(String file, boolean debug) throws IOException, CssException {		
 		HandlerImpl handler = new HandlerImpl(debug);
-		CssSource cs = new CssSource(f.getName(), new FileInputStream(f));
+		URL fileURL = this.getClass().getResource(CssInputStreamTest.PATH_TEST_BASE + file);
+		CssSource cs = new CssSource(fileURL.toString(), fileURL.openStream());
 		new CssParser().parse(cs.newReader(), CssLocation.NO_SID, handler, handler);
 		cs.getInputStream().close();
 		return handler;
@@ -1314,7 +1309,12 @@ public class CssParserTest {
 			}
 		}
 
-		public void declaration(CssDeclaration declaration) {	
+    @Override
+    public void endSelectors(List<CssSelector> sel) {
+      // do nothing
+    }
+
+    public void declaration(CssDeclaration declaration) {
 			declarations.add(declaration);
 			callbacks++;
 			if(print) {
